(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13808,        337]*)
(*NotebookOutlinePosition[     14727,        366]*)
(*  CellTagsIndexPosition[     14683,        362]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\n (*THE\ CHARACTERS\ SUB - PROGRAM*) \)\)], "Input"],

Cell["\<\
(*This program calculates up to 6 Cartan characters, and solution \
vectors, for a closed ideal of forms comprising; 'oneforms', 'twoforms', \
'threeforms', 'fourforms', and 'fiveforms'. The five separate lists of forms \
must be input with those names.
    The calculation uses random integers to construct the solution vectors, \
since in very large ideals symbolic vectors lead to overwhelming algebraic \
complexity. The parameter 'maxrandom' specifies the absolute value of the \
largest integer which can be randomly selected. Positive or negative values \
are also chosen at random. The smallest allowed value of 'maxrandom' is 3; if \
not specified, it defaults to 3.
   The integers generated during the calculation may become very large, so it \
is best to keep 'maxrandom' small at first, except for very simple ideals. \
Generally, the correct answer for the characters will be obtained in every \
run. The calculation should be repeated for a few trials, however, to guard \
against the occasional degeneracy. If the results from several trials are \
inconsistent, the value of 'maxrandom' will have to be increased to avoid \
accidental degeneracies.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*Select the first cell below and enter to bring up AVF and the \
program \"characters.m\", which contains the procedures to perform the \
calculation. The \"characters.nb\" Notebook contains it readable form. 
 Nb: it is always safer to start with a fresh Kernel.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(<< AVF.m; << characters.m\)\(\n\)
    \)\)], "Input"],

Cell[BoxData[""], "Input"],

Cell["\<\
(*To start a calculation, click in a titled cell below and enter. \
Initially, the forms in the ideal are output. The list of Cartan characters \
is output as it is generated. The calculation is finished when it prints \
\"Done.\"
    The  commands in \"Detailed Results\" at the very end of the program can \
then be executed after each calculation to display the results in detail (as \
explained there) and to repeat the calculation possibly with some minor \
changes.
    A different case can be run simply by selecting a new cell, with or \
without deleting the prior output. All results from a prior calculation will \
be lost by executing another one.
    A new problem can be inserted by copying one of these cells and making \
the appropriate changes in the coordinates or basis forms, and in the input \
lists of forms of the ideal. There must be an input list for each degree of \
forms, even if just the null list, {} . (Note: the \"characters\" program \
prunes the \"forms\" list to the basis 1-forms actually present in the ideal \
of oneforms, twoforms, etc. This subset is called \"idealforms\", and the \
remainder are in the List called \"absentforms\". The complete \"forms\" list \
and any previously defined \"drules\" for them are saved in the variables, \
\"saveforms\" and \"savedrules\", which can be used to be restore their \
original values when \"characters\" is Done.) Errors can sometimes arise from \
the Kernel remembering previous assignments; in that case it may be necessary \
to use the  Kernel: Quit Kernel menu command and to restart the program.*)
    \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \( (*The\ KdV\ ideal\ with\ 3\ 2 - forms\ in\ 5\ \(dimensions.\)*) \n\n
    makescalars[{x, t, u, p, z}]; \n
    oneforms = 
      \(twoforms = \(threeforms = \(fourforms = \(fiveforms = {}\)\)\)\); \n
    twoforms = {du\[Wedge]dt - z\ dx\[Wedge]dt, 
        dz\[Wedge]dx - p\ dx\[Wedge]dt, 
        du\[Wedge]dx - dp\[Wedge]dt - 12\ u\ z\ dx\[Wedge]dt}\n\), 
    \(maxrandom = 11; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[{
    \( (*A\ 2 - dim\ string, \ 
      embedded\ in\ flat\ 4 - dim\ spacetime.\n\tThe\ volume\ 2 - 
        form\ \[Theta]\_1\[Wedge]\[Theta]\_2\ is\ the\ Cartan\ form.\ The\n
      \tsubroutine\ ' embedsub\ ' constructs\ the\ necessary\ \n
      \tforms\ and\ bases.\ It\ can\ be\ inspected\ in\ the\ Notebook\n
      \tembed.nb.*) \n\n<< embed.m; embedsub[2, {\(-1\), 1, 1, 1}]\), 
    \(makescalars[{}]; \nthreeforms = \(fourforms = \(fiveforms = {}\)\); \n
    oneforms\), 
    \(twoforms = 
      Join[embeddingforms, fieldforms[\[Theta]\_1\[Wedge]\[Theta]\_2]]\n\), 
    \(maxrandom = 27; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[{
    \( (*The\ vacuum\ axi - stationary\ ideal\ with\ 6\ 2 - forms\n
      \t\tin\ 6\ \(dimensions.\)*) \n\n
    makescalars[{x, y, g, w, \[Phi], \[Psi]}]; \n
    oneforms = \(threeforms = \(fourforms = \(fiveforms = {}\)\)\); \n
    twoforms = {
        \(-\((dg\[Wedge]d\[Psi])\)\) - \(dw\[Wedge]d\[Phi]\)\/\[Phi]\^5, 
        \(w\ dg\[Wedge]dw\)\/2 - x\^2\ \[Phi]\^3\ dg\[Wedge]d\[Phi] + 
          dw\[Wedge]d\[Psi], 
        \(w\ dg\[Wedge]dx\)\/\(2\ x\) + \(dx\[Wedge]d\[Psi]\)\/x - 
          \(dy\[Wedge]d\[Phi]\)\/\[Phi], 
        \(-\(1\/2\)\)\ w\ dg\[Wedge]dy - \(x\ dx\[Wedge]d\[Phi]\)\/\[Phi] - 
          dy\[Wedge]d\[Psi], \[Phi]\^4\ dg\[Wedge]dy - \(dw\[Wedge]dx\)\/x, 
        \(-x\)\ \[Phi]\^4\ dg\[Wedge]dx - dw\[Wedge]dy}\n\), 
    \(maxrandom = 17; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[{
    \( (*A\ 4 - dim\ Riemannian\ spacetime\ embedded\ in\ a\n
      \t\tflat\ 10 - dim\ space.\ The\ subroutine\ ' embedsub\ '\n
      \t\ constructs\ the\ embedding\ 2 - 
        forms\ and\ bases.\n\t\tIn\ a\ problem\ such\ as\ this\ in\ which\ 
          each\ oneform\n
      \t\ consists\ only\ of\ a\ unique\ basis\ form, \ the\ oneforms\n
      \t\ can\ actually\ be\ omitted, \ so\ long\ as\ their\ closure\n
      \t\ 2 - forms\ are\ included.\ Doing\ so\ will\ reduce\ the\n
      \t\ length\ of\ the\ solution\ vectors, \ and\ may\ lessen\n
      \t\ the\ execution\ time.\ The\ program\ will\ give\ the\ \n
      \t\tfirst\ character, \ s\_0\  = \ 0\ , \ but\ its\ actual\ value\ is\ 
      \n
      \t\tclearly\ just\ the\ length\ of\ "\<oneforms\>", \ since\ they\n
      \t\ are\ all\ \(independent.\)*) \n\n<< embed.m; 
    embedsub[4, {\(-1\), 1, 1, 1, 1, 1, 1, 1, 1, 1}]\), 
    \(makescalars[{}]; \n
    oneforms = \(threeforms = \(fourforms = \(fiveforms = {}\)\)\); \n
    twoforms = embeddingforms\n\), 
    \(maxrandom = 9; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[{
    \( (*A\ 4 - dim\ Ricci - flat\ spacetime\ embedded\ in\ a\n
      \t\tflat\ 10 - dim\ space.\ The\ subroutine\ ' embedsub\ '\n
      \t\ constructs\ the\ Ricci\ 3 - forms, \ subR\[Theta], \ 
      and\ bases.\ \n\t\ This\ time\ the\ oneforms\ are\ included, \ although
      \ \n
      \t\tagain\ they\ could\ be\ \(omitted.\)*) \n\n<< embed.m; 
    embedsub[4, {\(-1\), 1, 1, 1, 1, 1, 1, 1, 1, 1}]\), 
    \(makescalars[{}]; \nfourforms = \(fiveforms = {}\); \noneforms\), 
    \(twoforms = embeddingforms\), 
    \(threeforms = subR\[Theta]\n\), 
    \(maxrandom = 5; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[{
    \( (*A\ 5 - dim\ Riemannian\ manifold\ embedded\ in\ a\ flat\ \n
      \t\t15 - dim\ space.The\ subroutine\ ' embedsub\ ' constructs\ \n
      \t\tthe\ embedding\ 2 - forms\ and\ \(bases.\)*) \n\n<< embed.m; 
    embedsub[5, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}]\), 
    \(makescalars[{}]; \nthreeforms = \(fourforms = \(fiveforms = {}\)\); \n
    oneforms\), 
    \(twoforms = embeddingforms\n\), 
    \(maxrandom = 3; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[{
    \( (*A\ 6 - dim\ Riemannian\ manifold\ embedded\ in\ a\ flat\ \n
      \t\t21 - dim\ space.The\ subroutine\ ' embedsub\ ' constructs\ \n
      \t\tthe\ embedding\ 2 - forms\ and\ bases.\ This\ problem\ is\n
      \t\tincluded\ simply\ to\ illustrate\ what\ happens\ for\n
      \t\ a\ case\ in\ which\ 6\ characters\ are\ not\ sufficient\n
      \t\ to\ give\ a\ complete\ result.\ However, \ the\ final\ \n
      \t\tanswer\ here\ is\ obvious, \ though\ it\ takes\ a\ \(while.\)*) \n
    \n<< embed.m; 
    embedsub[6, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
        1}]\), 
    \(makescalars[{}]; \nthreeforms = \(fourforms = \(fiveforms = {}\)\); \n
    oneforms\), 
    \(twoforms = embeddingforms\n\), 
    \(maxrandom = 3; characters; Print["\<Done.\>"]; \n\)}], "Input"],

Cell[BoxData[
    \(\n\)], "Input"],

Cell[BoxData[
    \(\( (*DETAILED\ RESULTS*) \n\)\)], "Input"],

Cell["\<\
(* The variable \"solutionvectors\" contains the independent \
vectors , v[i] ,  found. In large ideals these vectors may be very \
long.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(solutionvectors\n\)\)], "Input"],

Cell["\<\
(* \"involutoryvectors\" will show a set of independent vectors \
with the leftmost components in involution.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(involutoryvectors\n\)\)], "Input"],

Cell["\<\
(* \"allones\" shows all 1-forms generated during the \
calculation.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(allones\)], "Input"],

Cell[BoxData[
    \(Length[allones]\)], "Input"],

Cell["\<\
(*The procedure \"check\" first constructs an arbitrary linear \
combination of \"involutoryvectors\", called \"genvec\". It then contracts \
\"genvec\" on \"allones\", which must give zero for each of them. The list \
\"invset\" contains the involutory vector components; i.e., the leftmost \
non-zero components. Any of the original \"forms\" which do not appear in the \
ideal are obviously either Cauchy characteristics or basis oneforms that were \
deliberately omitted. They are in the variable, \"absentforms\". The routine \
\"cauchys\" attempts to find other potential Cauchy characteristics which \
annul the oneforms and twoforms, but does not investigate any higher degree \
forms.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(check\)], "Input"],

Cell[BoxData[
    \(genvec\)], "Input"],

Cell[BoxData[
    \(invset\)], "Input"],

Cell[BoxData[
    \(idealforms\)], "Input"],

Cell[BoxData[
    \(absentforms\)], "Input"],

Cell[BoxData[
    \(cauchys\)], "Input"],

Cell["\<\
(*To check independence for any subspace, the following commands \
can be changed to some other subset of \"forms\" and/or of solution \
vectors:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input"],

Cell[BoxData[
    \(sub = 
      forms[\([1]\)]\[Wedge]forms[\([2]\)]\[Wedge]forms[\([3]\)]\[Wedge]forms[
          \([4]\)]\)], "Input"],

Cell[BoxData[
    \(\(checkinvolution = 
      v[4]\[SmallCircle]v[3]\[SmallCircle]v[2]\[SmallCircle]v[1]
          \[SmallCircle]sub\n\t\)\)], "Input"],

Cell["\<\
(*Changing the order of the basis 1-forms in the \"forms\" list can \
be accomplished by executing the next cell to get the \"idealforms\" list and \
then re-ordering the output line. It will convert to input format with the \
first edit. Continue editing in this line. 
    When finished (being careful not to omit or duplicate any forms and/or \
commas), type , new = , in front of the new list and enter. Then execute the \
\"makeforms[new]\" statement. To change 'maxrandom' assign a new value in the \
next statement; if 'maxrandom' is not re-set, it will retain the previous \
value.
    Finally, select the \"characters\" cell and enter. Doing this last step \
alone will simply repeat a calculation with the same \"forms\" list and a \
randomly different set of integers selected from the same range.  
    Re-ordering the \"forms\" list can have a significant effect on the size \
of generated integers and so may have some effect on time and memory usage. \
As a general rule, placing the basis forms which appear more frequently in \
the ideal at the end of the list, gives smaller integers and a simpler \
solution.*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(idealforms\)], "Input"],

Cell[BoxData[
    \(makeforms[new]\)], "Input"],

Cell[BoxData[
    \(maxrandom\)], "Input"],

Cell[BoxData[
    \(characters; Print["\<Done.\>"]; \)], "Input"]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{671, 570},
WindowMargins->{{3, Automatic}, {Automatic, 2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@D=]B0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 75, 1, 43, "Input"],
Cell[1783, 53, 1214, 19, 204, "Input"],
Cell[3000, 74, 314, 6, 60, "Input"],
Cell[3317, 82, 77, 2, 43, "Input"],
Cell[3397, 86, 26, 0, 27, "Input"],
Cell[3426, 88, 1641, 26, 284, "Input"],
Cell[5070, 116, 449, 8, 139, "Input"],
Cell[5522, 126, 657, 11, 235, "Input"],
Cell[6182, 139, 832, 14, 246, "Input"],
Cell[7017, 155, 1110, 19, 331, "Input"],
Cell[8130, 176, 637, 11, 251, "Input"],
Cell[8770, 189, 496, 8, 203, "Input"],
Cell[9269, 199, 818, 14, 283, "Input"],
Cell[10090, 215, 35, 1, 43, "Input"],
Cell[10128, 218, 62, 1, 43, "Input"],
Cell[10193, 221, 187, 5, 44, "Input"],
Cell[10383, 228, 54, 1, 43, "Input"],
Cell[10440, 231, 159, 4, 28, "Input"],
Cell[10602, 237, 56, 1, 43, "Input"],
Cell[10661, 240, 118, 4, 28, "Input"],
Cell[10782, 246, 40, 1, 27, "Input"],
Cell[10825, 249, 48, 1, 27, "Input"],
Cell[10876, 252, 743, 12, 124, "Input"],
Cell[11622, 266, 38, 1, 27, "Input"],
Cell[11663, 269, 39, 1, 27, "Input"],
Cell[11705, 272, 39, 1, 27, "Input"],
Cell[11747, 275, 43, 1, 27, "Input"],
Cell[11793, 278, 44, 1, 27, "Input"],
Cell[11840, 281, 40, 1, 27, "Input"],
Cell[11883, 284, 195, 5, 44, "Input"],
Cell[12081, 291, 38, 1, 27, "Input"],
Cell[12122, 294, 137, 3, 27, "Input"],
Cell[12262, 299, 152, 3, 43, "Input"],
Cell[12417, 304, 1178, 19, 188, "Input"],
Cell[13598, 325, 43, 1, 27, "Input"],
Cell[13644, 328, 47, 1, 27, "Input"],
Cell[13694, 331, 42, 1, 27, "Input"],
Cell[13739, 334, 65, 1, 27, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

